==> intel-graphics-compiler_1.0.5353.1.orig.tar.gz: intel-graphics-compiler-igc-1.0.5353.1/IGC/VectorCompiler/lib/GenXCodeGen/GenXOCLInfoExtractor.cpp <==
/*===================== begin_copyright_notice ==================================

Copyright (c) 2017 Intel Corporation

Permission is hereby granted, free of charge, to any person obtaining a
copy of this software and associated documentation files (the
"Software"), to deal in the Software without restriction, including
without limitation the rights to use, copy, modify, merge, publish,
distribute, sublicense, and/or sell copies of the Software, and to
permit persons to whom the Software is furnished to do so, subject to
the following conditions:

The above copyright notice and this permission notice shall be included
in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.


======================= end_copyright_notice ==================================*/

#include "GenX.h"
#include "GenXOCLRuntimeInfo.h"
#include "llvm/Pass.h"
#include "Probe/Assertion.h"

using namespace llvm;

namespace llvm {
void initializeGenXOCLInfoExtractorPass(PassRegistry &PR);
}

class GenXOCLInfoExtractor : public ModulePass {
public:
  static char ID;

private:
  std::vector<GenXOCLRuntimeInfo::CompiledKernel> *Dest = nullptr;

public:
  StringRef getPassName() const override { return "GenX OCL Info Extractor"; }

  void getAnalysisUsage(AnalysisUsage &AU) const override {
    AU.addRequired<GenXOCLRuntimeInfo>();
  }

  GenXOCLInfoExtractor() : ModulePass(ID) {}

  GenXOCLInfoExtractor(std::vector<GenXOCLRuntimeInfo::CompiledKernel> &Dst)
      : ModulePass(ID), Dest(&Dst) {
    initializeGenXOCLInfoExtractorPass(*PassRegistry::getPassRegistry());
  }

  bool runOnModule(Module &M) override {
    IGC_ASSERT(Dest && "Expected dest to be initialized");
    auto &Info = getAnalysis<GenXOCLRuntimeInfo>();
    *Dest = Info.stealCompiledKernels();
    return false;
  }
};

char GenXOCLInfoExtractor::ID = 0;

INITIALIZE_PASS_BEGIN(GenXOCLInfoExtractor, "GenXOCLInfoExtractor",
                      "GenXOCLInfoExtractor", false, false)
INITIALIZE_PASS_DEPENDENCY(GenXOCLRuntimeInfo)
INITIALIZE_PASS_END(GenXOCLInfoExtractor, "GenXOCLInfoExtractor",
                    "GenXOCLInfoExtractor", false, false)

ModulePass *llvm::createGenXOCLInfoExtractorPass(
    std::vector<GenXOCLRuntimeInfo::CompiledKernel> &Dest) {
  return new GenXOCLInfoExtractor(Dest);
}

==> intel-graphics-compiler_1.0.15136.3.orig.tar.gz: intel-graphics-compiler-igc-1.0.15136.3/IGC/VectorCompiler/lib/GenXCodeGen/GenXOCLInfoExtractor.cpp <==
/*========================== begin_copyright_notice ============================

Copyright (C) 2020-2021 Intel Corporation

SPDX-License-Identifier: MIT

============================= end_copyright_notice ===========================*/

#include "GenX.h"

#include "vc/GenXCodeGen/GenXOCLRuntimeInfo.h"

#include "llvm/Pass.h"
#include "Probe/Assertion.h"

using namespace llvm;

namespace llvm {
void initializeGenXOCLInfoExtractorPass(PassRegistry &PR);
}

class GenXOCLInfoExtractor : public ModulePass {
public:
  static char ID;

private:
  GenXOCLRuntimeInfo::CompiledModuleT *Dest = nullptr;

public:
  StringRef getPassName() const override { return "GenX OCL Info Extractor"; }

  void getAnalysisUsage(AnalysisUsage &AU) const override {
    AU.addRequired<GenXOCLRuntimeInfo>();
  }

  GenXOCLInfoExtractor() : ModulePass(ID) {}

  GenXOCLInfoExtractor(GenXOCLRuntimeInfo::CompiledModuleT &Dst)
      : ModulePass(ID), Dest(&Dst) {
    initializeGenXOCLInfoExtractorPass(*PassRegistry::getPassRegistry());
  }

  bool runOnModule(Module &M) override {
    IGC_ASSERT_MESSAGE(Dest, "Expected dest to be initialized");
    auto &Info = getAnalysis<GenXOCLRuntimeInfo>();
    *Dest = Info.stealCompiledModule();
    return false;
  }
};

char GenXOCLInfoExtractor::ID = 0;

INITIALIZE_PASS_BEGIN(GenXOCLInfoExtractor, "GenXOCLInfoExtractor",
                      "GenXOCLInfoExtractor", false, false)
INITIALIZE_PASS_DEPENDENCY(GenXOCLRuntimeInfo)
INITIALIZE_PASS_END(GenXOCLInfoExtractor, "GenXOCLInfoExtractor",
                    "GenXOCLInfoExtractor", false, false)

ModulePass *llvm::createGenXOCLInfoExtractorPass(
    GenXOCLRuntimeInfo::CompiledModuleT &Dest) {
  return new GenXOCLInfoExtractor(Dest);
}
